export interface InitGroupDataParams<T> {
  data: T[] /** 需要成组的数据源,默认为一维数组 */
  key: keyof T | ((item: T) => string) /** 成组标志,值相同代表一组 */
}

export const useGroupData = <T>() => {
  const groupMap = ref<Record<string, T[]>>({})

  /** 初始化成组数据*/
  const initGroupData = (params: InitGroupDataParams<T>) => {
    const { data: groupData, key } = params
    resetData()
    groupData.forEach((item) => {
      let groupKey = ""
      if (typeof key === "string") {
        groupKey = key
        if (!groupMap.value[item[groupKey]]) {
          groupMap.value[item[groupKey]] = []
        }
        groupMap.value[item[groupKey]].push(item)
      } else if (typeof key === "function") {
        groupKey = key(item)
        if (!groupMap.value[groupKey]) {
          groupMap.value[groupKey] = []
        }
        groupMap.value[groupKey].push(item)
      }
    })
  }

  /** 重置成组数据 */
  const resetData = () => {
    groupMap.value = {}
  }

  return {
    groupMap,
    initGroupData,
  }
}
