import msgChannelApi from '@/api/msgChannelApi';
import msgMessageTypeApi from '@/api/msgMessageTypeApi';
import msgLevelApi from '@/api/msgLevelApi';
import msgChannelTemplateApi from '@/api/msgChannelTemplateApi';
import { tryit } from 'radash';
import type { IMsgMessageType } from '@/types/MsgMessageType';
import type { IAddMsgLevelEntry } from '@/types/MsgLevel';
import type { IMsgChannelTemplateEntry } from '@/types/MsgChannelTemplate';

interface commonParams {
  limit: number;
  page: number;
}
const params: commonParams = { limit: 1000, page: 1 };

// 消息渠道
export const useChannel = () => {
  const msgChannelList = ref();
  const fetch = async () => {
    const [, ret] = await tryit(msgChannelApi.findMessageChannelByPage)(params);
    if (ret?.code === 200)
      msgChannelList.value = ret.data.list.map((item) => {
        return {
          ...item,
          label: item.channelName,
          value: item.id
        };
      });
  };
  onMounted(() => fetch());
  return {
    msgChannelList
  };
};

// 消息类型
export const useMsgType = () => {
  const msgTypeList = ref<Array<IMsgMessageType>>([]);
  const fetch = async () => {
    const [, ret] = await tryit(msgMessageTypeApi.findMessageTypeByPage)(
      params
    );
    if (ret?.code === 200) {
      msgTypeList.value = ret.data.list.map((item: IMsgMessageType) => {
        return {
          ...item,
          label: item.typeName,
          value: item.id
        };
      });
    }
  };
  onMounted(() => fetch());
  return {
    msgTypeList
  };
};

// 消息级别
export const useMsgLevel = () => {
  const msgLevelList = ref<Array<IAddMsgLevelEntry>>([]);

  const fetch = async () => {
    const [, res] = await tryit(msgLevelApi.findMessageLevelByPage)(params);
    msgLevelList.value = res!.data.list.map((item: IAddMsgLevelEntry) => {
      return {
        ...item,
        label: item.levelName,
        value: item.id
      };
    });
  };
  onMounted(() => fetch());
  return { msgLevelList };
};

// 渠道模板
export const useChannelTemplate = () => {
  const msgChannelTemplate = ref<Array<IMsgChannelTemplateEntry>>([]);
  const fetch = async () => {
    const [, ret] = await tryit(
      msgChannelTemplateApi.findChannelTemplateByPage
    )(params);
    if (ret?.code === 200) {
      msgChannelTemplate.value = ret.data.list.map(
        (item: IMsgChannelTemplateEntry) => {
          return {
            ...item,
            label: item.templateName,
            value: item.id
          };
        }
      );
    }
  };
  onMounted(() => fetch());
  return {
    msgChannelTemplate
  };
};
